@@ -1,44 +1,34 @@
 import click
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.core.context import PulpAccessPolicyContext
 
-from pulpcore.cli.common.context import (
-    PluginRequirement,
-    PulpContext,
-    PulpEntityContext,
-    pass_entity_context,
-    pass_pulp_context,
-)
 from pulpcore.cli.common.generic import (
+    PulpCLIContext,
     href_option,
     list_command,
     load_json_callback,
+    lookup_callback,
+    pass_entity_context,
+    pass_pulp_context,
+    pulp_group,
     show_command,
     update_command,
 )
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.core.context import PulpAccessPolicyContext
 
 translation = get_translation(__name__)
 _ = translation.gettext
 
 
-def _vs_name_callback(ctx: click.Context, param: click.Parameter, value: str) -> str:
-    if value is not None:
-        entity_ctx = ctx.find_object(PulpEntityContext)
-        assert entity_ctx is not None
-        entity_ctx.entity = {"viewset_name": value}
-    return value
-
-
-@click.group()
+@pulp_group()
 @pass_pulp_context
 @click.pass_context
-def access_policy(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def access_policy(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     ctx.obj = PulpAccessPolicyContext(pulp_ctx)
 
 
 lookup_options = [
     href_option,
-    click.option("--viewset-name", callback=_vs_name_callback, expose_value=False),
+    click.option("--viewset-name", callback=lookup_callback("viewset_name"), expose_value=False),
 ]
 
 update_options = [
@@ -53,10 +43,9 @@ access_policy.add_command(update_command(decorators=lookup_options + update_opti
 
 @access_policy.command()
 @href_option
-@click.option("--viewset-name", callback=_vs_name_callback, expose_value=False)
+@click.option("--viewset-name", callback=lookup_callback("viewset_name"), expose_value=False)
 @pass_entity_context
 @pass_pulp_context
-def reset(pulp_ctx: PulpContext, access_policy_ctx: PulpAccessPolicyContext) -> None:
-    pulp_ctx.needs_plugin(PluginRequirement("core", min="3.17.dev"))
+def reset(pulp_ctx: PulpCLIContext, access_policy_ctx: PulpAccessPolicyContext) -> None:
     result = access_policy_ctx.reset()
     pulp_ctx.output_result(result)
