@@ -1,20 +1,28 @@
 from typing import IO
 
 import click
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.core.context import PulpArtifactContext
 
-from pulpcore.cli.common.context import PulpContext, pass_entity_context, pass_pulp_context
-from pulpcore.cli.common.generic import chunk_size_option, href_option, list_command, show_command
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.core.context import PulpArtifactContext
+from pulpcore.cli.common.generic import (
+    PulpCLIContext,
+    chunk_size_option,
+    href_option,
+    list_command,
+    pass_entity_context,
+    pass_pulp_context,
+    pulp_group,
+    show_command,
+)
 
 translation = get_translation(__name__)
 _ = translation.gettext
 
 
-@click.group()
+@pulp_group()
 @pass_pulp_context
 @click.pass_context
-def artifact(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def artifact(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     ctx.obj = PulpArtifactContext(pulp_ctx)
 
 
@@ -31,11 +39,10 @@ artifact.add_command(show_command(decorators=lookup_options))
 @pass_entity_context
 @pass_pulp_context
 def upload(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     artifact_ctx: PulpArtifactContext,
     file: IO[bytes],
     chunk_size: int,
 ) -> None:
-    artifact_href = artifact_ctx.upload(file, chunk_size)
-    result = artifact_ctx.show(artifact_href)
-    pulp_ctx.output_result(result)
+    artifact_ctx.upload(file, chunk_size)
+    pulp_ctx.output_result(artifact_ctx.entity)
