@@ -1,17 +1,17 @@
 import click
+from pulp_glue.common.context import PulpContentContext
+from pulp_glue.common.i18n import get_translation
 
-from pulpcore.cli.common.context import PulpContentContext, PulpContext, pass_pulp_context
-from pulpcore.cli.common.generic import list_command
-from pulpcore.cli.common.i18n import get_translation
+from pulpcore.cli.common.generic import PulpCLIContext, list_command, pass_pulp_context, pulp_group
 
 translation = get_translation(__name__)
 _ = translation.gettext
 
 
-@click.group()
+@pulp_group()
 @pass_pulp_context
 @click.pass_context
-def content(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def content(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     """
     Perform actions on all content units.
 
