@@ -1,26 +1,27 @@
-from typing import Iterable
+from typing import Any, Dict, Iterable
 
 import click
-
-from pulpcore.cli.common.context import (
+from pulp_glue.common.context import (
     EntityFieldDefinition,
-    PulpContext,
     PulpEntityContext,
     PulpRepositoryContext,
-    pass_entity_context,
-    pass_pulp_context,
     registered_repository_contexts,
 )
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.core.context import PulpExporterContext
+
 from pulpcore.cli.common.generic import (
+    PulpCLIContext,
     destroy_command,
     href_option,
     list_command,
     name_option,
+    pass_entity_context,
+    pass_pulp_context,
+    pulp_group,
     resource_option,
     show_command,
 )
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.core.context import PulpExporterContext
 
 translation = get_translation(__name__)
 _ = translation.gettext
@@ -39,7 +40,7 @@ multi_repository_option = resource_option(
 )
 
 
-@click.group()
+@pulp_group()
 def exporter() -> None:
     pass
 
@@ -47,7 +48,7 @@ def exporter() -> None:
 @exporter.group()
 @pass_pulp_context
 @click.pass_context
-def pulp(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def pulp(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     ctx.obj = PulpExporterContext(pulp_ctx)
 
 
@@ -67,7 +68,7 @@ pulp.add_command(destroy_command(decorators=lookup_options))
 @pass_entity_context
 @pass_pulp_context
 def create(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     exporter_ctx: PulpExporterContext,
     name: str,
     path: str,
@@ -94,23 +95,22 @@ def create(
 @pass_entity_context
 @pass_pulp_context
 def update(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     exporter_ctx: PulpExporterContext,
     path: str,
     repository: Iterable[EntityFieldDefinition],
     repository_href: Iterable[str],
 ) -> None:
-    the_exporter = exporter_ctx.entity
-    exporter_href = exporter_ctx.pulp_href
+    payload: Dict[str, Any] = {}
 
     if path:
-        the_exporter["path"] = path
+        payload["path"] = path
 
     if repository or repository_href:
-        the_exporter["repositories"] = [
+        payload["repositories"] = [
             repository_ctx.pulp_href
             for repository_ctx in repository
             if isinstance(repository_ctx, PulpEntityContext)
         ] + list(repository_href)
 
-    exporter_ctx.update(exporter_href, the_exporter)
+    exporter_ctx.update(body=payload)
