@@ -1,16 +1,21 @@
 from typing import Any
 
-import click
+from pulp_glue.common.context import PluginRequirement
+from pulp_glue.common.i18n import get_translation
 
-from pulpcore.cli.common.context import PluginRequirement, PulpContext, pass_pulp_context
-from pulpcore.cli.common.generic import load_json_callback, pulp_option
-from pulpcore.cli.common.i18n import get_translation
+from pulpcore.cli.common.generic import (
+    PulpCLIContext,
+    load_json_callback,
+    pass_pulp_context,
+    pulp_group,
+    pulp_option,
+)
 
 translation = get_translation(__name__)
 _ = translation.gettext
 
 
-@click.group()
+@pulp_group()
 def orphan() -> None:
     """
     Handle orphaned content.
@@ -23,7 +28,7 @@ def orphan() -> None:
     "--content-hrefs",
     help=_("List of specific Contents to delete if they are orphans"),
     callback=load_json_callback,
-    needs_plugins=[PluginRequirement("core", "3.14")],
+    needs_plugins=[PluginRequirement("core", "3.14.0")],
 )
 @pulp_option(
     "--protection-time",
@@ -33,15 +38,15 @@ def orphan() -> None:
         "How long in minutes Pulp should hold orphan Content and Artifacts before becoming"
         " candidates for cleanup task"
     ),
-    needs_plugins=[PluginRequirement("core", "3.15")],
+    needs_plugins=[PluginRequirement("core", "3.15.0")],
 )
 @pass_pulp_context
-def cleanup(pulp_ctx: PulpContext, **kwargs: Any) -> None:
+def cleanup(pulp_ctx: PulpCLIContext, **kwargs: Any) -> None:
     """
     Cleanup orphaned content.
     """
     body = {k: v for k, v in kwargs.items() if v is not None}
-    if pulp_ctx.has_plugin(PluginRequirement("core", "3.14")):
+    if pulp_ctx.has_plugin(PluginRequirement("core", "3.14.0")):
         result = pulp_ctx.call("orphans_cleanup_cleanup", body=body)
     else:
         result = pulp_ctx.call("orphans_delete")
