@@ -1,13 +1,12 @@
-import click
+from pulp_glue.common.i18n import get_translation
 
-from pulpcore.cli.common.context import PulpContext, pass_pulp_context
-from pulpcore.cli.common.i18n import get_translation
+from pulpcore.cli.common.generic import PulpCLIContext, pass_pulp_context, pulp_group
 
 translation = get_translation(__name__)
 _ = translation.gettext
 
 
-@click.group(deprecated=True)
+@pulp_group(deprecated=True)
 def orphans() -> None:
     """
     Use 'pulp orphan' instead.
@@ -17,7 +16,7 @@ def orphans() -> None:
 
 @orphans.command(deprecated=True)
 @pass_pulp_context
-def delete(pulp_ctx: PulpContext) -> None:
+def delete(pulp_ctx: PulpCLIContext) -> None:
     """
     Use pulp 'orphan cleanup' instead.
     """
