@@ -4,30 +4,26 @@ from datetime import datetime
 from typing import Optional, Tuple
 
 import click
+from pulp_glue.common.context import DATETIME_FORMATS, PluginRequirement, PulpEntityContext
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.core.context import PulpTaskContext
 
-from pulpcore.cli.common.context import (
-    PluginRequirement,
-    PulpContext,
-    PulpEntityContext,
-    pass_entity_context,
-    pass_pulp_context,
-)
 from pulpcore.cli.common.generic import (
+    PulpCLIContext,
     destroy_command,
     href_option,
     list_command,
+    pass_entity_context,
+    pass_pulp_context,
+    pulp_group,
     pulp_option,
     role_command,
 )
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.core.context import PulpTaskContext
 from pulpcore.cli.core.generic import task_filter
 
 translation = get_translation(__name__)
 _ = translation.gettext
 
-DATETIME_FORMATS = ["%Y-%m-%d", "%Y-%m-%dT%H:%M:%S"]
-
 
 def _uuid_callback(
     ctx: click.Context, param: click.Parameter, value: Optional[str]
@@ -47,18 +43,64 @@ uuid_option = pulp_option(
 )
 
 
-@click.group()
+@pulp_group()
 @pass_pulp_context
 @click.pass_context
-def task(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def task(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     ctx.obj = PulpTaskContext(pulp_ctx)
 
 
-task.add_command(list_command(decorators=task_filter))
+task.add_command(
+    list_command(
+        decorators=task_filter
+        + [
+            pulp_option(
+                "--reserved-resource",
+                "reserved_resources",
+                help=_("Href of a resource reserved by the task."),
+            ),
+            pulp_option(
+                "--reserved-resource-in",
+                "reserved_resources__in",
+                multiple=True,
+                help=_("Href of a resource reserved by the task. May be specified multiple times."),
+                needs_plugins=[PluginRequirement("core", min="3.22.0dev")],
+            ),
+            pulp_option(
+                "--exclusive-resource",
+                "exclusive_resources",
+                help=_("Href of a resource reserved exclusively by the task."),
+            ),
+            pulp_option(
+                "--exclusive-resource-in",
+                "exclusive_resources__in",
+                multiple=True,
+                help=_(
+                    "Href of a resource reserved exclusively by the task."
+                    " May be specified multiple times."
+                ),
+                needs_plugins=[PluginRequirement("core", min="3.22.0dev")],
+            ),
+            pulp_option(
+                "--shared-resource",
+                "shared_resources",
+                help=_("Href of a resource shared by the task."),
+            ),
+            pulp_option(
+                "--shared-resource-in",
+                "shared_resources__in",
+                multiple=True,
+                help=_("Href of a resource shared by the task. May be specified multiple times."),
+                needs_plugins=[PluginRequirement("core", min="3.22.0dev")],
+            ),
+        ]
+    )
+)
 task.add_command(destroy_command(decorators=[href_option, uuid_option]))
 task.add_command(
     role_command(
-        decorators=[href_option, uuid_option], needs_plugins=[PluginRequirement("core", min="3.17")]
+        decorators=[href_option, uuid_option],
+        needs_plugins=[PluginRequirement("core", min="3.17.0")],
     )
 )
 
@@ -69,7 +111,7 @@ task.add_command(
 @click.option("-w", "--wait", is_flag=True, help=_("Wait for the task to finish"))
 @pass_entity_context
 @pass_pulp_context
-def show(pulp_ctx: PulpContext, task_ctx: PulpTaskContext, wait: bool) -> None:
+def show(pulp_ctx: PulpCLIContext, task_ctx: PulpTaskContext, wait: bool) -> None:
     """Shows details of a task."""
     entity = task_ctx.entity
     if wait and entity["state"] in ["waiting", "running", "canceling"]:
@@ -91,7 +133,7 @@ def show(pulp_ctx: PulpContext, task_ctx: PulpTaskContext, wait: bool) -> None:
 @pass_entity_context
 @pass_pulp_context
 def cancel(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     task_ctx: PulpTaskContext,
     all_tasks: bool,
     waiting_tasks: bool,
@@ -104,7 +146,7 @@ def cancel(
     if running_tasks or all_tasks:
         states.append("running")
     if states:
-        tasks = task_ctx.list(limit=1 << 64, offset=0, parameters={"state__in": ",".join(states)})
+        tasks = task_ctx.list(limit=1 << 64, offset=0, parameters={"state__in": states})
         for task in tasks:
             with suppress(Exception):
                 task_ctx.cancel(task["pulp_href"])
@@ -146,12 +188,22 @@ def cancel(
 @pass_entity_context
 @pass_pulp_context
 def purge(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     task_ctx: PulpTaskContext,
     finished: Optional[datetime],
     state: Optional[Tuple[str]],
 ) -> None:
-    pulp_ctx.needs_plugin(PluginRequirement("core", "3.17.0.dev"))
+    pulp_ctx.needs_plugin(PluginRequirement("core", "3.17.0"))
     state_list = list(state) if state else None
-    finished_str = finished.strftime(DATETIME_FORMATS[1]) if finished else None
-    task_ctx.purge(finished_str, state_list)
+    task_ctx.purge(finished, state_list)
+
+
+@task.command()
+@pass_entity_context
+@pass_pulp_context
+def summary(pulp_ctx: PulpCLIContext, task_ctx: PulpTaskContext) -> None:
+    """
+    List a summary of tasks by status.
+    """
+    result = task_ctx.summary()
+    pulp_ctx.output_result(result)
