@@ -1,18 +1,25 @@
 import click
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.core.context import PulpWorkerContext
 
-from pulpcore.cli.common.context import PulpContext, pass_pulp_context
-from pulpcore.cli.common.generic import href_option, list_command, name_option, show_command
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.core.context import PulpWorkerContext
+from pulpcore.cli.common.generic import (
+    PulpCLIContext,
+    href_option,
+    list_command,
+    name_option,
+    pass_pulp_context,
+    pulp_group,
+    show_command,
+)
 
 translation = get_translation(__name__)
 _ = translation.gettext
 
 
-@click.group()
+@pulp_group()
 @pass_pulp_context
 @click.pass_context
-def worker(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def worker(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     ctx.obj = PulpWorkerContext(pulp_ctx)
 
 
