@@ -1,22 +1,26 @@
 import click
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.file.context import PulpFileDistributionContext, PulpFileRepositoryContext
 
-from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 from pulpcore.cli.common.generic import (
-    base_path_contains_option,
-    base_path_option,
+    PulpCLIContext,
+    common_distribution_create_options,
     create_command,
     destroy_command,
+    distribution_filter_options,
+    distribution_lookup_option,
     href_option,
     label_command,
-    label_select_option,
     list_command,
     name_option,
+    pass_pulp_context,
+    pulp_group,
+    pulp_labels_option,
     resource_option,
+    role_command,
     show_command,
     update_command,
 )
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.file.context import PulpFileDistributionContext, PulpFileRepositoryContext
 
 translation = get_translation(__name__)
 _ = translation.gettext
@@ -27,6 +31,7 @@ repository_option = resource_option(
     default_plugin="file",
     default_type="file",
     context_table={"file:file": PulpFileRepositoryContext},
+    href_pattern=PulpFileRepositoryContext.HREF_PATTERN,
     help=_(
         "Repository to be used for auto-distributing."
         " When set, this will unset the 'publication'."
@@ -35,7 +40,7 @@ repository_option = resource_option(
 )
 
 
-@click.group()
+@pulp_group()
 @click.option(
     "-t",
     "--type",
@@ -45,17 +50,16 @@ repository_option = resource_option(
 )
 @pass_pulp_context
 @click.pass_context
-def distribution(ctx: click.Context, pulp_ctx: PulpContext, distribution_type: str) -> None:
+def distribution(ctx: click.Context, pulp_ctx: PulpCLIContext, distribution_type: str) -> None:
     if distribution_type == "file":
         ctx.obj = PulpFileDistributionContext(pulp_ctx)
     else:
         raise NotImplementedError()
 
 
-filter_options = [label_select_option, base_path_option, base_path_contains_option]
-lookup_options = [href_option, name_option]
+lookup_options = [href_option, name_option, distribution_lookup_option]
+nested_lookup_options = [distribution_lookup_option]
 update_options = [
-    click.option("--base-path"),
     click.option(
         "--publication",
         help=_(
@@ -64,12 +68,16 @@ update_options = [
         ),
     ),
     repository_option,
+    pulp_labels_option,
 ]
-create_options = update_options + [click.option("--name", required=True)]
+create_options = common_distribution_create_options + update_options
 
-distribution.add_command(list_command(decorators=filter_options))
+distribution.add_command(list_command(decorators=distribution_filter_options))
 distribution.add_command(show_command(decorators=lookup_options))
 distribution.add_command(create_command(decorators=create_options))
-distribution.add_command(update_command(decorators=lookup_options + update_options))
+distribution.add_command(
+    update_command(decorators=lookup_options + update_options + [click.option("--base-path")])
+)
 distribution.add_command(destroy_command(decorators=lookup_options))
-distribution.add_command(label_command())
+distribution.add_command(label_command(decorators=nested_lookup_options))
+distribution.add_command(role_command(decorators=lookup_options))
