@@ -1,17 +1,21 @@
 import click
+from pulp_glue.common.context import PluginRequirement
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.file.context import PulpFilePublicationContext, PulpFileRepositoryContext
 
-from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 from pulpcore.cli.common.generic import (
+    PulpCLIContext,
     create_command,
     destroy_command,
     href_option,
     list_command,
+    pass_pulp_context,
     publication_filter_options,
+    pulp_group,
     resource_option,
+    role_command,
     show_command,
 )
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.file.context import PulpFilePublicationContext, PulpFileRepositoryContext
 
 translation = get_translation(__name__)
 _ = translation.gettext
@@ -22,10 +26,11 @@ repository_option = resource_option(
     default_plugin="file",
     default_type="file",
     context_table={"file:file": PulpFileRepositoryContext},
+    href_pattern=PulpFileRepositoryContext.HREF_PATTERN,
 )
 
 
-@click.group()
+@pulp_group()
 @click.option(
     "-t",
     "--type",
@@ -35,7 +40,7 @@ repository_option = resource_option(
 )
 @pass_pulp_context
 @click.pass_context
-def publication(ctx: click.Context, pulp_ctx: PulpContext, publication_type: str) -> None:
+def publication(ctx: click.Context, pulp_ctx: PulpCLIContext, publication_type: str) -> None:
     if publication_type == "file":
         ctx.obj = PulpFilePublicationContext(pulp_ctx)
     else:
@@ -53,7 +58,17 @@ create_options = [
         help=_("Filename to use for manifest file containing metadata for all the files."),
     ),
 ]
-publication.add_command(list_command(decorators=publication_filter_options))
+filter_options = publication_filter_options + [
+    resource_option(
+        "--repository",
+        default_plugin="file",
+        default_type="file",
+        context_table={"file:file": PulpFileRepositoryContext},
+        needs_plugins=[PluginRequirement("core", min="3.20.0")],
+    )
+]
+publication.add_command(list_command(decorators=filter_options))
 publication.add_command(show_command(decorators=lookup_options))
 publication.add_command(create_command(decorators=create_options))
 publication.add_command(destroy_command(decorators=lookup_options))
+publication.add_command(role_command(decorators=lookup_options))
