@@ -2,46 +2,49 @@ from typing import Any, Dict, List, Optional
 
 import click
 import schema as s
-
-from pulpcore.cli.common.context import (
+from pulp_glue.common.context import (
     EntityFieldDefinition,
     PluginRequirement,
-    PulpContext,
-    PulpEntityContext,
     PulpRemoteContext,
     PulpRepositoryContext,
-    pass_pulp_context,
-    pass_repository_context,
 )
-from pulpcore.cli.common.generic import (
-    GroupOption,
-    create_command,
-    create_content_json_callback,
-    destroy_command,
-    href_option,
-    label_command,
-    label_select_option,
-    list_command,
-    load_json_callback,
-    name_option,
-    pulp_option,
-    repository_content_command,
-    repository_href_option,
-    repository_option,
-    resource_option,
-    retained_versions_option,
-    show_command,
-    update_command,
-    version_command,
-)
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.core.generic import task_command
-from pulpcore.cli.file.context import (
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.file.context import (
     PulpFileContentContext,
     PulpFileRemoteContext,
     PulpFileRepositoryContext,
 )
 
+from pulpcore.cli.common.generic import (
+    GroupOption,
+    PulpCLIContext,
+    create_command,
+    create_content_json_callback,
+    destroy_command,
+    href_option,
+    json_callback,
+    label_command,
+    label_select_option,
+    list_command,
+    load_file_wrapper,
+    name_option,
+    pass_pulp_context,
+    pass_repository_context,
+    pulp_group,
+    pulp_labels_option,
+    pulp_option,
+    repository_content_command,
+    repository_href_option,
+    repository_lookup_option,
+    resource_option,
+    retained_versions_option,
+    role_command,
+    show_command,
+    update_command,
+    version_command,
+)
+from pulpcore.cli.core.generic import task_command
+
 translation = get_translation(__name__)
 _ = translation.gettext
 
@@ -52,15 +55,13 @@ remote_option = resource_option(
     default_type="file",
     context_table={"file:file": PulpFileRemoteContext},
     href_pattern=PulpRemoteContext.HREF_PATTERN,
-    help=_(
-        "Remote used for synching in the form '[[<plugin>:]<resource_type>:]<name>' or by href."
-    ),
+    help=_("Remote used for syncing in the form '[[<plugin>:]<resource_type>:]<name>' or by href."),
 )
 
 
 def _content_callback(ctx: click.Context, param: click.Parameter, value: Any) -> Any:
     if value:
-        pulp_ctx = ctx.find_object(PulpContext)
+        pulp_ctx = ctx.find_object(PulpCLIContext)
         assert pulp_ctx is not None
         ctx.obj = PulpFileContentContext(pulp_ctx, entity=value)
     return value
@@ -69,10 +70,12 @@ def _content_callback(ctx: click.Context, param: click.Parameter, value: Any) ->
 CONTENT_LIST_SCHEMA = s.Schema([{"sha256": str, "relative_path": s.And(str, len)}])
 
 
-def _content_list_callback(ctx: click.Context, param: click.Parameter, value: Any) -> Any:
-    result = load_json_callback(ctx, param, value)
-    if result is None:
+@load_file_wrapper
+def _content_list_callback(ctx: click.Context, param: click.Parameter, value: Optional[str]) -> Any:
+    if value is None:
         return None
+
+    result = json_callback(ctx, param, value)
     try:
         return CONTENT_LIST_SCHEMA.validate(result)
     except s.SchemaError as e:
@@ -83,7 +86,7 @@ def _content_list_callback(ctx: click.Context, param: click.Parameter, value: An
         )
 
 
-@click.group()
+@pulp_group()
 @click.option(
     "-t",
     "--type",
@@ -93,15 +96,15 @@ def _content_list_callback(ctx: click.Context, param: click.Parameter, value: An
 )
 @pass_pulp_context
 @click.pass_context
-def repository(ctx: click.Context, pulp_ctx: PulpContext, repo_type: str) -> None:
+def repository(ctx: click.Context, pulp_ctx: PulpCLIContext, repo_type: str) -> None:
     if repo_type == "file":
         ctx.obj = PulpFileRepositoryContext(pulp_ctx)
     else:
         raise NotImplementedError()
 
 
-lookup_options = [href_option, name_option]
-nested_lookup_options = [repository_href_option, repository_option]
+lookup_options = [href_option, name_option, repository_lookup_option]
+nested_lookup_options = [repository_href_option, repository_lookup_option]
 update_options = [
     click.option("--description"),
     remote_option,
@@ -112,6 +115,7 @@ update_options = [
         default=None,
     ),
     retained_versions_option,
+    pulp_labels_option,
 ]
 create_options = update_options + [click.option("--name", required=True)]
 file_options = [
@@ -164,24 +168,29 @@ repository.add_command(
         modify_decorators=modify_options,
     )
 )
+repository.add_command(role_command(decorators=lookup_options))
 
 
 @repository.command()
 @name_option
 @href_option
+@repository_lookup_option
 @remote_option
 @pass_repository_context
 def sync(
     repository_ctx: PulpRepositoryContext,
     remote: EntityFieldDefinition,
 ) -> None:
-    repository = repository_ctx.entity
-    repository_href = repository_ctx.pulp_href
-
+    """
+    Sync the repository from a remote source.
+    If remote is not specified sync will try to use the default remote associated with
+    the repository
+    """
     body: Dict[str, Any] = {}
+    repository = repository_ctx.entity
 
-    if isinstance(remote, PulpEntityContext):
-        body["remote"] = remote.pulp_href
+    if remote:
+        body["remote"] = remote
     elif repository["remote"] is None:
         raise click.ClickException(
             _(
@@ -190,22 +199,20 @@ def sync(
             ).format(name=repository["name"])
         )
 
-    repository_ctx.sync(
-        href=repository_href,
-        body=body,
-    )
+    repository_ctx.sync(body=body)
 
 
 @repository.command(deprecated=True)
 @name_option
 @href_option
+@repository_lookup_option
 @click.option("--sha256", required=True)
 @click.option("--relative-path", required=True)
 @click.option("--base-version", type=int)
 @pass_repository_context
 @pass_pulp_context
 def add(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     repository_ctx: PulpRepositoryContext,
     sha256: str,
     relative_path: str,
@@ -225,7 +232,6 @@ def add(
     ).pulp_href
 
     repository_ctx.modify(
-        href=repository_href,
         add_content=[content_href],
         base_version=base_version_href,
     )
@@ -234,13 +240,14 @@ def add(
 @repository.command(deprecated=True)
 @name_option
 @href_option
+@repository_lookup_option
 @click.option("--sha256", required=True)
 @click.option("--relative-path", required=True)
 @click.option("--base-version", type=int)
 @pass_repository_context
 @pass_pulp_context
 def remove(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     repository_ctx: PulpRepositoryContext,
     sha256: str,
     relative_path: str,
@@ -260,7 +267,6 @@ def remove(
     ).pulp_href
 
     repository_ctx.modify(
-        href=repository_href,
         remove_content=[content_href],
         base_version=base_version_href,
     )
@@ -269,6 +275,7 @@ def remove(
 @repository.command(deprecated=True)
 @name_option
 @href_option
+@repository_lookup_option
 @click.option("--base-version", type=int)
 @click.option(
     "--add-content",
@@ -295,7 +302,7 @@ def remove(
 @pass_repository_context
 @pass_pulp_context
 def modify(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     repository_ctx: PulpRepositoryContext,
     add_content: List[Dict[str, str]],
     remove_content: List[Dict[str, str]],
@@ -318,7 +325,6 @@ def modify(
     ]
 
     repository_ctx.modify(
-        href=repository_href,
         add_content=add_content_href,
         remove_content=remove_content_href,
         base_version=base_version_href,
