@@ -1,14 +1,20 @@
 import click
 
-from pulpcore.cli.common.context import PulpContext, pass_pulp_context
-from pulpcore.cli.common.generic import href_option, list_command, show_command
+from pulpcore.cli.common.generic import (
+    PulpCLIContext,
+    href_option,
+    list_command,
+    pass_pulp_context,
+    pulp_group,
+    show_command,
+)
 from pulpcore.cli.migration.context import (
     PulpMigrationPulp2ContentContext,
     PulpMigrationPulp2RepositoryContext,
 )
 
 
-@click.group()
+@pulp_group()
 def pulp2() -> None:
     pass
 
@@ -16,7 +22,7 @@ def pulp2() -> None:
 @pulp2.group()
 @pass_pulp_context
 @click.pass_context
-def content(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def content(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     ctx.obj = PulpMigrationPulp2ContentContext(pulp_ctx)
 
 
@@ -27,7 +33,7 @@ content.add_command(show_command(decorators=[href_option]))
 @pulp2.group()
 @pass_pulp_context
 @click.pass_context
-def repository(ctx: click.Context, pulp_ctx: PulpContext) -> None:
+def repository(ctx: click.Context, pulp_ctx: PulpCLIContext) -> None:
     ctx.obj = PulpMigrationPulp2RepositoryContext(pulp_ctx)
     pass
 
