@@ -2,16 +2,15 @@ import gettext
 from typing import IO, Optional
 
 import click
+from pulp_glue.common.context import EntityFieldDefinition, PulpEntityContext
+from pulp_glue.rpm.context import PulpRpmCompsXmlContext, PulpRpmRepositoryContext
 
-from pulpcore.cli.common.context import (
-    EntityFieldDefinition,
-    PluginRequirement,
-    PulpContext,
-    PulpEntityContext,
+from pulpcore.cli.common.generic import (
+    PulpCLIContext,
     pass_pulp_context,
+    pulp_command,
+    resource_option,
 )
-from pulpcore.cli.common.generic import resource_option
-from pulpcore.cli.rpm.context import PulpRpmCompsXmlContext, PulpRpmRepositoryContext
 
 _ = gettext.gettext
 
@@ -25,19 +24,18 @@ repository_option = resource_option(
 )
 
 
-@click.command()
+@pulp_command()
 @click.option("--file", type=click.File("rb"), required=True)
 @repository_option
 @click.option("--replace", type=bool, default=False)
 @pass_pulp_context
 def comps_upload(
-    pulp_ctx: PulpContext,
+    pulp_ctx: PulpCLIContext,
     file: IO[bytes],
     repository: Optional[EntityFieldDefinition],
     replace: Optional[bool],
 ) -> None:
     """Create comps.xml content-units by uploading a comps.xml-formatted file"""
-    pulp_ctx.needs_plugin(PluginRequirement("rpm", min="3.17.0dev"))
     entity_ctx = PulpRpmCompsXmlContext(pulp_ctx)
     href = None
     if isinstance(repository, PulpEntityContext):
