@@ -1,22 +1,25 @@
 import click
+from pulp_glue.common.i18n import get_translation
+from pulp_glue.rpm.context import PulpRpmDistributionContext, PulpRpmRepositoryContext
 
-from pulpcore.cli.common.context import PulpContext, pass_pulp_context
 from pulpcore.cli.common.generic import (
-    base_path_contains_option,
-    base_path_option,
+    PulpCLIContext,
+    common_distribution_create_options,
     create_command,
     destroy_command,
+    distribution_filter_options,
+    distribution_lookup_option,
     href_option,
     label_command,
-    label_select_option,
     list_command,
     name_option,
+    pass_pulp_context,
+    pulp_group,
+    pulp_labels_option,
     resource_option,
     show_command,
     update_command,
 )
-from pulpcore.cli.common.i18n import get_translation
-from pulpcore.cli.rpm.context import PulpRpmDistributionContext, PulpRpmRepositoryContext
 
 translation = get_translation(__name__)
 _ = translation.gettext
@@ -31,10 +34,11 @@ repository_option = resource_option(
         " When set, this will unset the 'publication'."
         " Specified as '[[<plugin>:]<type>:]<name>' or as href."
     ),
+    href_pattern=PulpRpmRepositoryContext.HREF_PATTERN,
 )
 
 
-@click.group()
+@pulp_group()
 @click.option(
     "-t",
     "--type",
@@ -44,17 +48,16 @@ repository_option = resource_option(
 )
 @pass_pulp_context
 @click.pass_context
-def distribution(ctx: click.Context, pulp_ctx: PulpContext, distribution_type: str) -> None:
+def distribution(ctx: click.Context, pulp_ctx: PulpCLIContext, distribution_type: str) -> None:
     if distribution_type == "rpm":
         ctx.obj = PulpRpmDistributionContext(pulp_ctx)
     else:
         raise NotImplementedError()
 
 
-filter_options = [label_select_option, base_path_option, base_path_contains_option]
-lookup_options = [href_option, name_option]
+lookup_options = [href_option, name_option, distribution_lookup_option]
+nested_lookup_options = [distribution_lookup_option]
 update_options = [
-    click.option("--base-path"),
     click.option(
         "--publication",
         help=_(
@@ -63,14 +66,15 @@ update_options = [
         ),
     ),
     repository_option,
+    pulp_labels_option,
 ]
-create_options = update_options + [
-    click.option("--name", required=True),
-]
+create_options = common_distribution_create_options + update_options
 
-distribution.add_command(list_command(decorators=filter_options))
+distribution.add_command(list_command(decorators=distribution_filter_options))
 distribution.add_command(show_command(decorators=lookup_options))
 distribution.add_command(create_command(decorators=create_options))
-distribution.add_command(update_command(decorators=lookup_options + update_options))
+distribution.add_command(
+    update_command(decorators=lookup_options + update_options + [click.option("--base-path")])
+)
 distribution.add_command(destroy_command(decorators=lookup_options))
-distribution.add_command(label_command())
+distribution.add_command(label_command(decorators=nested_lookup_options))
